==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/de-if/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Benutzerdefinierte Felder',
    'manage'                    => 'Verwalten',
    'field'		                => 'Feld',
    'about_fieldsets_title'		=> 'Über Feldsätze',
    'about_fieldsets_text'		=> 'Ein Feldsatz ist eine Gruppe von benutzerdefinierten Feldern, die häufig für bestimmte Asset-Modelltypen wiederverwendet werden.',
    'custom_format'             => 'Benutzerdefiniertes Regex-Format...',
    'encrypt_field'      	        => 'Den Wert dieses Feldes in der Datenbank verschlüsseln',
    'encrypt_field_help'      => 'WARNUNG: Ein verschlüsseltes Feld kann nicht durchsucht werden.',
    'encrypted'      	        => 'Verschlüsselt',
    'fieldset'      	        => 'Feldsatz',
    'qty_fields'      	      => 'Anzahl Felder',
    'fieldsets'      	        => 'Feldsätze',
    'fieldset_name'           => 'Feldsatzname',
    'field_name'              => 'Feldname',
    'field_values'            => 'Feldwerte',
    'field_values_help'       => 'Füge eine wählbare Option pro Zeile hinzu. Leere Zeilen, außer der ersten, werden ignoriert.',
    'field_element'           => 'Formularelement',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Benutzerdefiniertes Regex-Format',
    'field_custom_format_help'     => 'In diesem Feld kannst du einen Regex-Ausdruck zur Validierung verwenden. Er sollte mit "regex:" beginnen. Um beispielsweise zu validieren, dass ein benutzerdefiniertes Feld eine gültige IMEI (15 numerische Ziffern) enthält, würdest du <code>regex:/^[0-9]{15}$/</code> nutzen.',
    'required'   		          => 'Pflichtfeld',
    'req'   		              => 'Erf.',
    'used_by_models'   		    => 'Von Modellen benutzt',
    'order'   		            => 'Reihenfolge',
    'create_fieldset'         => 'Neuer Feldsatz',
    'update_fieldset'         => 'Feldsatz aktualisieren',
    'fieldset_does_not_exist'   => 'Feldsatz :id existiert nicht',
    'fieldset_updated'         => 'Feldsatz aktualisiert',
    'create_fieldset_title' => 'Neuen Feldsatz erstellen',
    'create_field'            => 'Neues benutzerdefiniertes Feld',
    'create_field_title' => 'Neues benutzerdefiniertes Feld erstellen',
    'value_encrypted'      	        => 'Der Wert dieses Feldes ist in der Datenbank verschlüsselt. Nur Benutzer mit Administratorrechten können den entschlüsselten Wert anzeigen',
    'show_in_email'     => 'Feld miteinbeziehen bei Herausgabe-Emails an die Benutzer? Verschlüsselte Felder können nicht miteinbezogen werden',
    'show_in_email_short'     => 'In E-Mails einbeziehen.',
    'help_text' => 'Hilfetext',
    'help_text_description' => 'Dies ist ein optionaler Text, der unter den Formularelementen erscheint, während eine Datei bearbeitet wird, um Kontext für das Feld bereitzustellen.',
    'about_custom_fields_title' => 'Über benutzerdefinierte Felder',
    'about_custom_fields_text' => 'Benutzerdefinierte Felder ermöglichen es, beliebige Attribute zu Assets hinzuzufügen.',
    'add_field_to_fieldset' => 'Feld zum Feldsatz hinzufügen',
    'make_optional' => 'Benötigt - klicken, um optional zu machen',
    'make_required' => 'Optional - Klicken, um erforderlich zu machen',
    'reorder' => 'Erneut bestellen',
    'db_field' => 'Datenbankfeld',
    'db_convert_warning' => 'WARNUNG. Dieses Feld befindet sich in der Tabelle mit benutzerdefinierten Feldern als <code>:db_column</code> sollte aber <code>:expected</code> sein.',
    'is_unique' => 'Dieser Wert muss für jedes Asset einzigartig sein',
    'unique' => 'Einzigartig',
    'display_in_user_view' => 'Erlaube dem Benutzer, an den das Asset herausgegeben wurde, diese Werte auf der Seite "Zugeordnete Assets anzeigen" anzeigen zu lassen',
    'display_in_user_view_table' => 'Für Benutzer sichtbar',
    'auto_add_to_fieldsets' => 'Automatisch zu jedem neuen Feldsatz hinzufügen',
    'add_to_preexisting_fieldsets' => 'Zu allen existierenden Feldsätzen hinzufügen',
    'show_in_listview' => 'Standardmäßig in Listenansichten anzeigen. Berechtigte Benutzer können weiterhin über die Spaltenauswahl ein-/ausblenden',
    'show_in_listview_short' => 'In Listen anzeigen',
    'show_in_requestable_list_short' => 'In anforderbarer Asset-Liste anzeigen',
    'show_in_requestable_list' => 'Wert in der anforderbaren Asset-Liste anzeigen. Verschlüsselte Felder werden nicht angezeigt',
    'encrypted_options' => 'Dieses Feld ist verschlüsselt, so dass einige Display-Optionen nicht verfügbar sind.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/de-if/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Benutzerdefinierte Felder',
    'manage'                    => 'Verwalten',
    'field'		                => 'Feld',
    'about_fieldsets_title'		=> 'Über Feldsätze',
    'about_fieldsets_text'		=> 'Ein Feldsatz ist eine Gruppe von benutzerdefinierten Feldern, die häufig für bestimmte Asset-Modelltypen wiederverwendet werden.',
    'custom_format'             => 'Benutzerdefiniertes Regex-Format...',
    'encrypt_field'      	        => 'Den Wert dieses Feldes in der Datenbank verschlüsseln',
    'encrypt_field_help'      => 'WARNUNG: Ein verschlüsseltes Feld kann nicht durchsucht werden.',
    'encrypted'      	        => 'Verschlüsselt',
    'fieldset'      	        => 'Feldsatz',
    'qty_fields'      	      => 'Anzahl Felder',
    'fieldsets'      	        => 'Feldsätze',
    'fieldset_name'           => 'Feldsatzname',
    'field_name'              => 'Feldname',
    'field_values'            => 'Feldwerte',
    'field_values_help'       => 'Füge eine wählbare Option pro Zeile hinzu. Leere Zeilen, außer der ersten, werden ignoriert.',
    'field_element'           => 'Formularelement',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Benutzerdefiniertes Regex-Format',
    'field_custom_format_help'     => 'In diesem Feld kannst du einen Regex-Ausdruck zur Validierung verwenden. Er sollte mit "regex:" beginnen. Um beispielsweise zu validieren, dass ein benutzerdefiniertes Feld eine gültige IMEI (15 numerische Ziffern) enthält, würdest du <code>regex:/^[0-9]{15}$/</code> nutzen.',
    'required'   		          => 'Pflichtfeld',
    'req'   		              => 'Erf.',
    'used_by_models'   		    => 'Von Modellen benutzt',
    'order'   		            => 'Reihenfolge',
    'create_fieldset'         => 'Neuer Feldsatz',
    'update_fieldset'         => 'Feldsatz aktualisieren',
    'fieldset_does_not_exist'   => 'Feldsatz :id existiert nicht',
    'fieldset_updated'         => 'Feldsatz aktualisiert',
    'create_fieldset_title' => 'Neuen Feldsatz erstellen',
    'create_field'            => 'Neues benutzerdefiniertes Feld',
    'create_field_title' => 'Neues benutzerdefiniertes Feld erstellen',
    'value_encrypted'      	        => 'Der Wert dieses Feldes ist in der Datenbank verschlüsselt. Nur Benutzer mit Administratorrechten können den entschlüsselten Wert anzeigen',
    'show_in_email'     => 'Feld miteinbeziehen bei Herausgabe-Emails an die Benutzer? Verschlüsselte Felder können nicht miteinbezogen werden',
    'show_in_email_short' => 'In E-Mails einbeziehen',
    'help_text' => 'Hilfetext',
    'help_text_description' => 'Dies ist ein optionaler Text, der unter den Formularelementen erscheint, während eine Datei bearbeitet wird, um Kontext für das Feld bereitzustellen.',
    'about_custom_fields_title' => 'Über benutzerdefinierte Felder',
    'about_custom_fields_text' => 'Benutzerdefinierte Felder ermöglichen es, beliebige Attribute zu Assets hinzuzufügen.',
    'add_field_to_fieldset' => 'Feld zum Feldsatz hinzufügen',
    'make_optional' => 'Benötigt - klicken, um optional zu machen',
    'make_required' => 'Optional - Klicken, um erforderlich zu machen',
    'reorder' => 'Erneut bestellen',
    'db_field' => 'Datenbankfeld',
    'db_convert_warning' => 'WARNUNG. Dieses Feld befindet sich in der Tabelle mit benutzerdefinierten Feldern als <code>:db_column</code> sollte aber <code>:expected</code> sein.',
    'is_unique' => 'Dieser Wert muss für jedes Asset einzigartig sein',
    'unique' => 'Einzigartig',
    'display_in_user_view' => 'Erlaube dem Benutzer, an den das Asset herausgegeben wurde, diese Werte auf der Seite "Zugeordnete Assets anzeigen" anzeigen zu lassen',
    'display_in_user_view_table' => 'Für Benutzer sichtbar',
    'auto_add_to_fieldsets' => 'Automatisch zu jedem neuen Feldsatz hinzufügen',
    'add_to_preexisting_fieldsets' => 'Zu allen existierenden Feldsätzen hinzufügen',
    'show_in_listview' => 'Standardmäßig in Listenansichten anzeigen. Berechtigte Benutzer können weiterhin über die Spaltenauswahl ein-/ausblenden',
    'show_in_listview_short' => 'In Listen anzeigen',
    'show_in_requestable_list_short' => 'In anforderbarer Asset-Liste anzeigen',
    'show_in_requestable_list' => 'Wert in der anforderbaren Asset-Liste anzeigen. Verschlüsselte Felder werden nicht angezeigt',
    'encrypted_options' => 'Dieses Feld ist verschlüsselt, so dass einige Display-Optionen nicht verfügbar sind.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
